==> haskell-checkers-0.6.0-116-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-7c9rIKQU5EJ4fncxozYNYY
key:                  checkers-0.6.0-7c9rIKQU5EJ4fncxozYNYY
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  87ca8595702088aed8d194ea457aed92
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.2.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-7c9rIKQU5EJ4fncxozYNYY
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED array-0.5.4.0
    base-4.16.4.0 random-1.2.1.2-JIamRYdFYdY4e3nutT9Pr4
    semigroupoids-5.3.7-8VadR23YqgWJtKdu0uOLHe

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.6.0-125-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 checkers
version:              0.6.0
visibility:           public
id:                   checkers-0.6.0-7rmuQXPTB2fHJ1XmyqLTon
key:                  checkers-0.6.0-7rmuQXPTB2fHJ1XmyqLTon
license:              BSD-3-Clause
copyright:            (c) 2008-2013 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott
stability:            experimental
homepage:             https://github.com/haskell-checkers/checkers
synopsis:             Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.

    &#169; 2008-2013 by Conal Elliott; BSD3 license.

category:             Testing
abi:                  7641ccf653d7a8c3075e00fc2382e74d
exposed:              True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils

hidden-modules:       Control.Monad.Extensions
import-dirs:          /usr/lib/ghc-9.2.8/site-local/checkers-0.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/checkers-0.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-checkers
hs-libraries:         HScheckers-0.6.0-7rmuQXPTB2fHJ1XmyqLTon
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X array-0.5.4.0
    base-4.16.4.0 random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh
    semigroupoids-5.3.7-3HMcZlsRlqoKaeVPumQFHg

haddock-interfaces:   /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html:         /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
